ADDITIONAL_URLS = '--additional-urls'
CONFIG_FILE = '--config-file'
FORMAT = '--format'
LOG_FILE = '--log-file'
LOG_FORMAT = '--log-format'
LOG_LEVEL = '--log-level'
TIMEOUT = '--timeout'
BUILD_CACHE_PATH = '--build-cache-path'
BUILD_PATH = '--build-path'
BUILD_PROPERTY = '--build-property'
FQBN = '--fqbn'
OUTPUT = '--output'
UPLOAD = '--upload'
PREPROCESS = '--preprocess'
SHOW_PROPERTIES = '--show-properties'
VID_PID = '--vid-pid'
WARNINGS = '--warnings'
DEST_DIR = '--dest-dir'
VERIFY = '--verify'
INPUT = '--input'
PORT = '--port'
UPDATABLE = '--updatable'
NAMES = '--names'
ALL = '--all'
DAEMONIZE = '--daemonize'
LIBRARIES = '--libraries'
OPTIMIZE_FOR_DEBUG = '--optimize-for-debug'
INTERPRETER = '--interpreter'
FULL = '--full'
PROGRAMMER = '--programmer'
OUTPUT_DIR = '--output-dir'
NO_DESCRIPTION = '--no-description'
INPUT_DIR = '--input-dir'
LIST_PROGRAMMERS = '--list-programmers'
RUN_POST_INSTALL = '--run-post-install'
SKIP_POST_INSTALL = '--skip-post-install'
INCLUDE_BUILD_DIR = '--include-build-dir'
SHOW_OUTDATED = '--show-outdated'
INPUT_FILE = '--input-file'
WATCH = '--watch'
SHOW_HIDDEN = '--show-hidden'
CLEAN = '--clean'
EXPORT_BINARIES = '--export-binaries'
DEST_FILE = '--dest-file'
OVERWRITE = '--overwrite'
INFO = '--info'
GIT_URL = '--git-url'
ZIP_PATH = '--zip-path'
ONLY_COMPILATION_DATABASE = '--only-compilation-database'
LIBRARY = '--library'
